#
# spec file for package python3-ipa
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without test
Name:           python3-ipa
Version:        1.0.0
Release:        lp150.1.1
Summary:        Command line and API for testing custom images
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
Url:            https://github.com/SUSE/ipa
Source:         https://files.pythonhosted.org/packages/source/p/python3-ipa/python3-ipa-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%if %{with test}
BuildRequires:  python3-PyYAML
BuildRequires:  python3-apache-libcloud
BuildRequires:  python3-azure-common
BuildRequires:  python3-azure-mgmt-compute
BuildRequires:  python3-azure-mgmt-network
BuildRequires:  python3-azure-mgmt-resource
BuildRequires:  python3-click
BuildRequires:  python3-coverage
BuildRequires:  python3-cryptography
BuildRequires:  python3-paramiko
BuildRequires:  python3-pycrypto
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-testinfra
%endif
Requires:       python3-PyYAML
Requires:       python3-apache-libcloud
Requires:       python3-azure-common
Requires:       python3-azure-mgmt-compute
Requires:       python3-azure-mgmt-network
Requires:       python3-azure-mgmt-resource
Requires:       python3-click
Requires:       python3-cryptography
Requires:       python3-paramiko
Requires:       python3-pycrypto
Requires:       python3-pytest
Requires:       python3-testinfra
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
ipa provides a command line utility to test images in
the Public Cloud (AWS, Azure, GCE, etc.).

%package tests
Summary:        Infrastructure tests for ipa
Group:          Development/Languages/Python
PreReq:         python3-ipa = %{version}
Requires:       python3-susepubliccloudinfo

%description tests
Directory of infrastructure tests for testing images.

%prep
%setup -q -n python3-ipa-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d -m 755 %{buildroot}/%{_mandir}/man1
install -m 644 man/man1/*.1 %{buildroot}/%{_mandir}/man1

install -d -m 755 %{buildroot}/usr
cp -r usr/* %{buildroot}/usr/

%check
%if %{with test}
export LC_ALL=en_US.utf-8
export LANG=en_US.utf-8
python3 -m pytest --cov=ipa --ignore=tests/data --ignore=usr
%endif

%files
%defattr(-,root,root)
%doc CHANGES.asciidoc CONTRIBUTING.asciidoc LICENSE README.asciidoc
%doc %{_mandir}/man1/*
%{_bindir}/ipa
%{python3_sitelib}/*

%files tests
%defattr(-,root,root)
%dir /usr/share/lib
%dir /usr/share/lib/ipa
/usr/share/lib/ipa/*

%changelog
* Fri Mar 30 2018 sean.marlow@suse.com
- Update to v1.0.0 (2018-03-30)
  + Tests argument is now optional.
  + This allows for the use of --no-cleanup option to start an
    instance in the given framework.
  + Add regression test to check for valid UUID on SLES instance
    in EC2.
  + Add regression test to confirm lscpu binary returns successful
    exit code.
  + Subnet option has been added to launch a new instance in the
    given network/subnet (--subnet-id).
  + Remove requirement on case with distro and provider options.
  + Use Testinfra run module to check hostname. System Info module
    was removed from package.
  + Migrate Azure provider to the ARM (resource manager API).
  + Add option to use user-data for loading SSH public key to
    instance in EC2.
  + Add delete history item option to results command.
* Tue Dec 12 2017 sean.marlow@suse.com
- Update to v0.5.1.
  + Cleanup MANIFEST.
  + Fix README.
* Tue Dec 12 2017 sean.marlow@suse.com
- Update to v0.5.0
  + Allow EC2 testing without a config file.
  + Use cpe_name to determine SAP product in SLES tests.
  + Update README overview with more info.
  + Provide log_file and results_file in results dict.
  + Other formatting and bug fixes.
- Update spec to point at pypi source.
* Thu Oct 12 2017 sean.marlow@suse.com
- Update to v0.4.0
  + Migrate EC2 provider to apache-libcloud.
  + Remove vcrpy integration tests.
* Thu Sep 21 2017 sean.marlow@suse.com
- Update to v0.3.0
  + Add SLES update infrastructure tests.
  + Add test_dirs to args for test endpoint.
  + Fix bug if test fails before sync point.
  + Add command line option --no-default-test-dirs.
  + Add skipped tests to results output.
  + Update man pages and and cleanup docs.
* Wed Sep 13 2017 sean.marlow@suse.com
- Update to v0.2.0
  + Add test suite for testing SLES images.
  + Add SLES tests to MANIFEST.
  + Fix change log in MANIFEST.
  + Ignore SLES tests in setup.cfg.
  + Fix ipa provider test, include region and platform in results dict.
  + Add tests package to spec and mv to python3-ipa.spec.
  + Pass region and platform to pytest for use in tests.
- Update to v0.1.3
  + Check format of unit/integration tests.
  + Run flake8 on tests in tox/travis.
  + Cleanup flake8 format in azure integration test.
- Update to v0.1.2
  + Check host key does not change.
  + After soft and hard reboot ensure host key has not changed.
- Update to v0.1.1
  + Sync spec file.
  + Python3 format spec instead of Python single spec.
  + Add missing requirements for GCE to spec.
- Update to v0.1.0
  + Integrate GCE provider using apache-libcloud.
* Wed Aug 30 2017 sean.marlow@suse.com
- Update to v0.0.5
  + Explicit ignore of tests/data directory in spec file.
* Wed Aug 30 2017 sean.marlow@suse.com
- Update to v0.0.4
  + Account for classes and parameterized tests.
- Update to v0.0.3
  + Cleanup azure unit tests.
- Update to v0.0.2
  + Update Travis to build only master + tags.
  + Use deault dicts in results summary.
  + Clenaup error message usage.
  + Add shebang to shell script.
  + Use yaml safe_load.
  + Spelling fixes.
  + Cleanup spec file.
* Tue Aug 29 2017 sean.marlow@suse.com
- Account for older versions of pytest.
  + Explicitly ignore tests/data directory.
* Tue Aug 22 2017 sean.marlow@suse.com
- Update spec for python3 only.
* Wed Aug 16 2017 sean.marlow@suse.com
- Initial release v0.0.1 2017-08-16
